@@ -34,14 +34,16 @@ sub generator {
 sub count {
     my ($self) = @_;
     my $name = $self->name;
-    my $res  = $self->store->solr->search(qq/_bag:"$name"/, {rows => 0});
+    my $res  = $self->store->solr->search(qq/_bag:"$name"/,
+            {rows => 0, facet => "false", spellcheck => "false"});
     $res->content->{response}{numFound};
 }
 
 sub get {
     my ($self, $id) = @_;
     my $name = $self->name;
-    my $res  = $self->store->solr->search(qq/_bag:"$name" AND _id:"$id"/, {rows => 1});
+    my $res  = $self->store->solr->search(qq/_bag:"$name" AND _id:"$id"/,
+        {rows => 1, facet => "false", spellcheck => "false"});
     my $hit  = $res->content->{response}{docs}->[0] || return;
     delete $hit->{_bag};
     $hit;
